@@ -1,5 +1,6 @@
 use serde::*;
-use std::sync::Arc;
+use std::fmt;
+use std::{fmt::Display, sync::Arc};
 use wasm_bus::macros::*;
 
 #[wasm_bus(format = "bincode")]
@@ -41,3 +42,14 @@ pub enum StdioMode {
     Null,
     Log,
 }
+
+impl Display for StdioMode {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        match self {
+            StdioMode::Piped => write!(f, "piped"),
+            StdioMode::Inherit => write!(f, "inherit"),
+            StdioMode::Null => write!(f, "null"),
+            StdioMode::Log => write!(f, "log"),
+        }
+    }
+}
